@@ -3,6 +3,8 @@ import glob
 import pprint
 from typing import List
 
+from pydmt.configs import ConfigTarget
+
 
 def hlp_source_under(folder):
     """
@@ -63,9 +65,22 @@ def make_hlp_wrap(level):
 def collect_reqs(args: List[str]):
     # pylint: disable=import-outside-toplevel
     import config.python
-    # pylint: disable=no-member
-    args.extend(config.python.test_requires)
-    args.extend(config.python.run_requires)
-    args.extend(config.python.install_requires)
-    args.extend(config.python.setup_requires)
-    args.extend(config.python.dev_requires)
+    if hasattr(config.python, "test_requires") and os.path.isdir("tests"):
+        args.extend(config.python.test_requires)
+    if hasattr(config.python, "run_requires"):
+        args.extend(config.python.run_requires)
+    if hasattr(config.python, "install_requires"):
+        args.extend(config.python.install_requires)
+    if hasattr(config.python, "setup_requires"):
+        args.extend(config.python.setup_requires)
+    if hasattr(config.python, "dev_requires") and ConfigTarget.dev:
+        args.extend(config.python.dev_requires)
+
+
+def get_install_args(args):
+    args.extend([
+        "python",
+        "-m",
+        "pip",
+        "install",
+    ])
